@@ -15,7 +15,7 @@ use strict;
 use vars qw($VERSION);
 use 5.004;
 
-$VERSION = "0.17005"; 
+$VERSION = "0.17006"; 
 
 use overload (
 	'""'	   =>	'stringify',
@@ -32,13 +32,13 @@ $Error::THROWN = undef;	# last error thrown, a workaround until die $ref works
 my $LAST;		# Last error created
 my %ERROR;		# Last error associated with package
 
-sub throw_Error_Simple
+sub _throw_Error_Simple
 {
     my $args = shift;
     return Error::Simple->new($args->{'text'});
 }
 
-$Error::ObjectifyCallback = \&throw_Error_Simple;
+$Error::ObjectifyCallback = \&_throw_Error_Simple;
 
 
 # Exported subs are defined in Error::subs
@@ -121,10 +121,6 @@ sub stacktrace {
     $text;
 }
 
-# Allow error propagation, ie
-#
-# $ber->encode(...) or
-#    return Error->prior($ber)->associate($ldap);
 
 sub associate {
     my $err = shift;
@@ -144,6 +140,12 @@ sub associate {
     return;
 }
 
+=head2 Error->new()
+
+See the Error::Simple documentation.
+
+=cut
+
 sub new {
     my $self = shift;
     my($pkg,$file,$line) = caller($Error::Depth);
@@ -262,6 +264,12 @@ package Error::Simple;
 
 @Error::Simple::ISA = qw(Error);
 
+=head2 Error->new()
+
+See the Error::Simple documentation.
+
+=cut
+
 sub new {
     my $self  = shift;
     my $text  = "" . shift;
@@ -328,7 +336,7 @@ sub run_clauses ($$$\@) {
 		    $code = $catch->[$i+1];
 		    while(1) {
 			my $more = 0;
-			local($Error::THROWN);
+			local($Error::THROWN, $@);
 			my $ok = eval {
 			    $@ = $err;
 			    if($wantarray) {
@@ -364,7 +372,7 @@ sub run_clauses ($$$\@) {
 	if(defined($owise = $clauses->{'otherwise'})) {
 	    my $code = $clauses->{'otherwise'};
 	    my $more = 0;
-        local($Error::THROWN);
+        local($Error::THROWN, $@);
 	    my $ok = eval {
 		$@ = $err;
 		if($wantarray) {
@@ -836,6 +844,13 @@ The line where the constructor of this error was called from
 
 The text of the error
 
+=item $err->associate($obj)
+
+Associates an error with an object to allow error propagation. I.e:
+
+    $ber->encode(...) or
+        return Error->prior($ber)->associate($ldap);
+
 =back
 
 =head2 OVERLOAD METHODS
@@ -865,9 +880,7 @@ to the constructor.
 
 =head1 PRE-DEFINED ERROR CLASSES
 
-=over 4
-
-=item Error::Simple
+=head2 Error::Simple
 
 This class can be used to hold simple error strings and values. It's
 constructor takes two arguments. The first is a text value, the second
@@ -881,7 +894,6 @@ of the error object.
 This class is used internally if an eval'd block die's with an error
 that is a plain string. (Unless C<$Error::ObjectifyCallback> is modified)
 
-=back
 
 =head1 $Error::ObjectifyCallback
 
